### The template wavelength solution for SONG-China
- thar_line_list
    ThAr line list, copied from IRAF, air wavelength?
- thar_temp.dump & wave_temp.dump
    SONG ThAr wavelength solution template
